@@ -9,6 +9,9 @@ version = __version__
 
 from .ubxmessage import UBXMessage
 from .exceptions import UBXMessageError, UBXParseError, UBXTypeError
-from .ubxtypes import *
+from .ubxtypes_core import *
+from .ubxtypes_get import *
+from .ubxtypes_set import *
+from .ubxtypes_poll import *
 
 parse = UBXMessage.parse
